The New York Times - Breaking News, World News & Multimedia
Description: The New York Times: Find breaking news, multimedia, reviews & opinion on Washington, business, sports, movies, travel, books, jobs, education, real estate, cars & more at nytimes.com.
Keywords: Illegal Immigration,United States Politics and Government,Customs and Border Protection (US),Immigration and Customs Enforcement (US),Trump, Donald J,Executive Orders and Memorandums,Terrorism,Kelly, John F (1950- ),Homeland Security Department,Trump, Donald J,Democratic National Committee,Perez, Thomas E,Ellison, Keith,United States Politics and Government,Atlanta (Ga),North American Free Trade Agreement,Ross, Wilbur L Jr,Mexico City (Mexico),International Trade and World Market,Labor and Jobs,Trump, Donald J,United States Politics and Government,Trump, Donald J,News and News Media,United States Politics and Government,Bannon, Stephen K,Spicer, Sean M (1971- ),New York City,Trump, Donald J,North Korea,United States International Relations,United States Politics and Government,Coulter, Shannon (1971- ),Boycotts,Shopping and Retail,Trump, Ivanka,Trump, Donald J,United States Politics and Government,Grab Your Wallet,National Debt (US),Trump, Donald J,Health Insurance and Managed Care,Med [cell cut: 4874 characters, first 1000 kept]

NYTimes.com no longer supports Internet Explorer 9 or earlier. Please upgrade your browser. LEARN MORE »

## Top News

###### The 45th President

## Agents Discover Freedom on Deportations Under Trump

By NICHOLAS KULISH, CAITLIN DICKERSON and RON NIXON 12:26 PM ET

- The Trump administration’s plan to deport vast numbers of undocumented immigrants was introduced in dramatic fashion over the past month.
- Much of the front-line work has fallen to thousands of ICE officers who are newly emboldened and empowered.

- ## People From 7 Travel-Ban Nations Pose No Increased Terror Risk, Report Says

###### Breaking News

## Democrats Elect
Ex-Labor Secretary as Chairman

By JONATHAN MARTIN 3:59 PM ET

In a vote that showed the Democratic Party has yet to heal the wounds of last year’s presidential primary, former Labor Secretary Thomas E. Perez beat Representative Keith Ellison of Minnesota to become D.N.C. chairman.

## For Commerce Pick, ‘Inherently Bad’ Deals Paid Off

By AZAM AHMED and ELISABETH MALKIN 1:20 PM ET

Wilbur Ross, who amassed a fortune with help from trade deals like Nafta, has vowed to tear up those deals if confirmed as commerce secretary.

## Trump Ruled Tabloid Media. Washington Is a Different Story.

By GLENN THRUSH and MICHAEL M. GRYNBAUM 12:57 PM ET

President Trump was no stranger back in the day to the art of news management. But even that did not seem to prepare him for the capital press corps.

## White House Cancels Back-Channel Talks With North Korea

By JANE PERLEZ 1:51 PM ET

The reversal came after an announcement that a chemical weapon was used to kill the estranged half brother of Kim Jong-un, North Korea’s leader.

## Meet the Anti-Trump Activist Who Is Taking On Retailers

By RACHEL ABRAMS

Putting together a list of companies selling Trump products has transformed Shannon Coulter’s life, and not always for the better.

### MORE IN POLITICS

- ## National Debt Dips. Trump Crows. Well, Sure, but … 1:36 PM ET

## The Adults Left Behind if Medicaid Adds Job Mandate

By ABBY GOODNOUGH 1:54 PM ET

Republican governors want to reverse what they consider an incentive not to work, but critics say putting employment before health care is backward.

## Health Law’s Key Figure Lives in State That Embraced It

By ROBERT PEAR 11:40 AM ET

Representative Greg Walden of Oregon, where the Affordable Care Act has been a success, leads a committee that will have a large role in drafting a replacement.

## Tunisia at Odds Over Return of Thousands of Jihadists

By CARLOTTA GALL 11:20 AM ET

Secularists have raised fears that a wave of returning Tunisians who joined the ranks of the Islamic State will bring further mayhem to their country.

# Got a confidential news tip?

## The New York Times offers several ways to get in touch with and provide materials to our journalists. Learn more.

### UNDERGROUND RAILROAD

#

## Harriet Tubman’s Path
to Freedom

By RON STODGHILL

How one woman transformed the marshy, wooded Chesapeake Bay region, first a gateway through which slave traders brought Africans, into a route to liberation.

Comments

###### The Daily 360

1:36

## Florida’s Forgotten ‘Above-Ground’…

Chris Carmichael for The New York Times. Technology by Samsung.

More in

The Daily 360 »

- ## In Florida, Solemn Shadows of the Early Underground Railroad

- ## In Ohio, a Warrior Against Slavery

- ## Pittsburgh’s Underground Railroad, Preserved and Not

- ## Exploring Detroit’s Sites

- ## At Ontario Sites, Farming and Liberty

- ## On a New York Tour, Lessons in Resistance

Support the mission of The Times. Sponsor a student subscription today.

###### Smarter Living

### Watching

## Oscars 2017: Where to Stream the Nominated Movies

By SCOTT TOBIAS

Several Oscar-nominated films are still in theaters. Here’s where you can stream the rest.

### Itineraries

## Which ‘Trusted Traveler’ Program Is Right for You?

By MICHELLE HIGGINS

Several fast check-in programs accommodate various domestic and international travelers, and even baseball fans.

## Amazon Deforestation, Once Tamed, Comes Roaring Back

By HIROKO TABUCHI, CLAIRE RIGBY and JEREMY WHITE

A decade after the “Save the Rainforest” movement captured the world’s imagination, Cargill and other food giants are pushing deeper into the wilderness.

- ## How Far to the Next Forest? A New Way to Measure Deforestation

## Uber Lawsuit Puts Spotlight on Rush for Driverless Cars

By MIKE ISAAC and DAISUKE WAKABAYASHI

The suit, brought by the autonomous car business Waymo, accuses Uber and a star engineer, Anthony Levandowski, of planning to steal trade secrets.

## In the Lakers Family Business, Spectacle and Drama

By BILLY WITZ 1:34 PM ET

The team’s front-office shake-up is the latest high-profile episode for a team that has long been the N.B.A. standard-bearer for soap opera storylines.

Comments

## Buffett, in Annual Letter, Offers Hymn to U.S. Economy

By LANDON THOMAS Jr. 12:10 PM ET

The billionaire investor Warren Buffett’s optimistic tone contrasts with President Trump’s darker descriptions. Mr. Buffett also gave credit to “ambitious immigrants.”

## D.I.Y. Coffin Clubs Catch On in New Zealand

By MICHELLE INNIS 2:06 PM ET

Coffin-building clubs have gained popularity among older residents looking beyond traditional social activities.

###### Oscars 2017

## Make Your Picks on Our Oscar Ballot

See this year’s Oscar nominees and make your picks. Voting will close on Sunday at 8:30 p.m. Eastern time.

- ## And the Oscar Winners Will Be ...

- ## U.S. Blocks Syrian Rescue Worker From Attending the Oscars

- ## Where the Best Picture Nominees Are Liked the Most

- ## Foreign-Film Nominees Denounce Fanaticism and Nationalism

## ‘I Hope to Have My Mind Boggled a Few More Times’

By LELA MOORE and CYNTHIA COLLINS

Our Top 10 Comments of the Week: Readers debate new planets, transgender issues and pizza toppings.

## Choosing Amputation for a More Active Life in New York

By SERENA SOLOMON

Prosthetic limbs are an increasingly common sight in the city. But what sets Adam Taylor’s situation apart from most is that he elected to have his right leg removed below the knee.

## 10 Things to Do in NYC This Weekend and Beyond

By LOUIS LUCERO II

It’s a big city, with plenty to do, see and hear.

### More News

- ## ISIS Kills 10 Police Officers in Ambush in Afghanistan 1:14 PM ET

- ## Attacks on 2 Syrian Security Offices Kill Dozens 1:11 PM ET

- ## After Welcoming Immigrants, Sweden Debates Implications

- ## Ethiopian Marathoner in Exile Finds Sanctuary in Arizona

- ## Obama Takes In Broadway Show, but Shuns Spotlight

## The Interpreter

The Interpreter brings sharp insight and context to the major news stories of the week. Sign up to get it by email.

##

## The Last Act for the Ringling Circus

Yes, the three-ring circus can seem like a relic. But something irreplaceable will be lost when this tent is closed for good.

## Take It Slow for Roman Cocktail Hour

Aperitivo time is that blessed and blissful hour (or two, or three) of easygoing snacking and drinking and talking, when time slows and stress slips away.

## Into the Land of Polka Dots and Mirrors

An exhibition at the Smithsonian’s Hirshhorn Museum focuses on the mirrored-room environments of Yayoi Kusama, a fixture of popular culture.

## The Opinion Pages

## Trump Is Damaging Press Freedom Worldwide

By JOEL SIMON 1:02 PM ET

The president’s war on the media emboldens autocrats who kill and imprison journalists.

## Where Are All the Other Muslims?

By JAKE HALPERN and MICHAEL SLOAN

Life in America is a lot to get used to.

### Editorials

- ## Calling Secretary Tillerson

- ## Under Mr. Trump, Private Prisons Thrive Again

- ## Barring the White House Press Corps From the White House

## Playing Poker With World War II and Vietnam

By BRUCE HOLBERT 3:01 PM ET

“I didn’t take two bullets over there for the government. I didn’t take them for no president.”

- ## The Islamophobic Huckster in the White House

- ## My Night in Town Hall Hell

- ## @realDonaldTrump’s Twitchy Twitter Fingers

- ## Join us on Facebook »

## User Subscriptions

- ## Good, Bad and Mad: Andrew Rosenthal on the News

- ## 1928 | ニューヨーク・タイムス, a Home 6,700 Miles Away From Home

### Times Insider »

## Good, Bad and Mad: Andrew Rosenthal on the News

### The Crossword »

## Play Today’s Puzzle

### The Crossword »

## Play Today’s Puzzle

### Wordplay »

## Your Reading List

Stories you save are added to your Reading List.

Here are some suggestions to get started.

#### Weekend Reads

## From Our Advertisers

Loading...

## timesvideo

explore all videos »
Video Player

## Inside Nytimes.com

## Sections

## World »

- ### For Commerce Pick Wilbur Ross, ‘Inherently Bad’ Deals Paid Off

- ## U.S. Wary of Its New Neighbor in Djibouti: A Chinese Naval Base

- ## ‘Affordable Underground Furniture’: D.I.Y. Coffin Clubs Catch On in New Zealand

## Business Day »

- ### The Anti-Trump Activist Taking On Retailers

- ## Trump Ruled the Tabloid Media. Washington Is a Different Story.

- ## Trump Intensifies His Attacks on Journalists and Condemns F.B.I. ‘Leakers’

## Opinion »

- ### Op-Ed Contributor: Trump Is Damaging Press Freedom in the U.S. and Abroad

- ## Editorial: Calling Secretary Tillerson

- ## Op-Ed Contributor: My Night in Town Hall Hell

## U.S. »

- ### Trump Immigration Policies Pose Conflict for Police in ‘Sanctuary Cities’

- ## Hate Crime Is Feared as 2 Indian Engineers Are Shot in Kansas

- ## Trump Talk Rattles Aerospace Industry, Up and Down Supply Chain

## Technology »

- ### A Lawsuit Against Uber Highlights the Rush to Conquer Driverless Cars

- ## Snapchat Founders’ Grip Tightened After a Spat With an Early Investor

- ## Google Self-Driving Car Unit Accuses Uber of Using Stolen Technology

## Arts »

- ### The Carpetbagger: And the Oscar Winners Will Be ...

- ## 32 Reasons to Get Out & Off the Couch

- ## Oscars 2017: Test Your Knowledge

## Politics »

- ### Democrats Elect Thomas Perez, Establishment Favorite, as Party Chairman

- ## White House Memo: Will Trump Take 'Brutally Forthright’ Advice From McMaster?

- ## People From 7 Travel-Ban Nations Pose No Increased Terror Risk, Report Says

## Fashion & Style »

- ### Eduardo García’s Path: Migrant Worker, Convict, Deportee, Star Chef

- ## Red Carpet Watch: The Irresistible Style of Emma Stone

- ## Fashion Review: Modern Potboilers at Prada and Moschino

## Movies »

- ### The Carpetbagger: And the Oscar Winners Will Be ...

- ## Where Oscar Best Picture Nominees Are Liked Most

- ## Foreign-Film Nominees Unite to Denounce ‘Rise of Fanaticism’

## New York »

- ### Hipster Cop Retires. The Nickname Still Applies.

- ## Obama Takes In a Broadway Show, but Shuns the Spotlight

- ## End of Era Looms as Waldorf Astoria Prepares for Hiatus

## Sports »

- ### In the Lakers Family Business, Spectacle and Drama Continue

- ## In a Champion’s Corner, a Real Coach Who Inspired One on ‘The Wire’

- ## On Baseball: With Each Hit, Rockies’ D.J. LeMahieu Shows Cubs’ Epstein What He Gave Up On

## Theater »

- ### 32 Reasons to Get Out & Off the Couch

- ## Review: ‘Sunday in the Park With George,’ a Living Painting to Make You See

- ## Obama Takes In a Broadway Show, but Shuns the Spotlight

## Science »

- ### 7 Earth-Size Planets Orbit Dwarf Star, NASA and European Astronomers Say

- ## ScienceTake: Bumblebees Demonstrate the Power of Insect Brains

- ## Trilobites: ‘Ring of Fire’ Solar Eclipse Will Cross South America and Africa on Sunday

## Obituaries »

- ### Cardinal Desmond Connell, Dublin Archbishop During Abuse Scandal, Dies at 90

- ## Mildred Dresselhaus, the Queen of Carbon, Dies at 86

- ## Jerome Tuccille, Libertarian Author and Trump Biographer, Dies at 79

## Television »

- ### Lena Dunham and Matthew Rhys on the Latest ‘Girls’ Provocation

- ## Walter Presents: A Chic TV Boutique With a Foreign Accent

- ## A Word With: Jason Jones Moves ‘The Detour’ From Trailer Park to Central Park

## Health »

- ### Doctors Consider a Last Best Hope for Obese Teenagers: Surgery

- ## The New Old Age: Gorsuch Staunchly Opposes ‘Aid in Dying.’ Does It Matter?

- ## Singing While Pregnant

## Travel »

- ### Underground Railroad: Harriet Tubman’s Path to Freedom

- ## Underground Railroad: On a New York Underground Railroad Tour, Lessons in Resistance

- ## 36 Hours: 36 Hours in Trinidad

## Books »

- ### Fiction: In the Japanese Hit ‘Six Four,’ a Police Inspector Weighs Questions of Loyalty

- ## Further Reading: A History of Race and Racism in America, in 24 Chapters

- ## By the Book: Chelsea Clinton: By the Book

## Education »

- ### Trump Rescinds Rules on Bathrooms for Transgender Students

- ## Rough First Week Gives Betsy DeVos a Glimpse of the Fight Ahead

- ## Beyond ‘Hidden Figures’: Nurturing New Black and Latino Math Whizzes

## Food »

- ### City Kitchen: A Croque-Madame Dressed Up With Crab

- ## A Good Appetite: A Vegetable Tart, but Nothing Too Dainty

- ## Your Next Lesson: Ribeira Sacra

## Sunday Review »

- ### Opinion: Our Putin

- ## Masha Gessen: In Praise of Hypocrisy

- ## Opinion: The Power of Movies to Change Our Hearts

## Real Estate »

- ### Small Co-ops: The Good, the Bad and the Ugly

- ## The High End: Lenny Kravitz, Interior Designer

- ## 360 View: Steve Miller Sues to Get Out of Buying a House

## The Upshot »

- ### Economic Trends: The Big Question for the U.S. Economy: How Much Room Is There to Grow?

- ## Economic View: Economists Have Been Demoted in Washington. That’s a Bad Idea.

- ## School Choice: Dismal Voucher Results Surprise Researchers as DeVos Era Begins

## Magazine »

- ### The Future of Work: The Jobs Americans Do

- ## The Future of Work: The Future of Not Working

- ## The Future of Work: Learning to Love Our Robot Co-Workers

## Automobiles »

- ### Video Review: 2017 Volkswagen Golf GTI SE

- ## Common Sense: Cadillac Ad Tries to Bridge Nation’s Chasm, Without Falling In

- ## Wheels: Self-Driving Cars Might Need Standards, but Whose?

## T Magazine »

- ### Women’s Fashion Shows: Prada, Fendi, Emilio Pucci, Moschino

- ## Illustrated Interview | Anderson Cooper

- ## Backstage Beauty Report: How to Make Eyes Pop — Without the Appearance of Liner

## Times Insider »

- ### What We’re Reading

- ## Looking Back: 1928 | ニューヨーク・タイムス, a Home 6,700 Miles Away From Home

- ## Insider Podcasts: Good, Bad and Mad: Andrew Rosenthal on the News

## Real Estate »

### What You Get

## $1,700,000 Homes in Connecticut, Minnesota and Montana

By MIKE POWELL

An 18th-century colonial in Warren, Conn.; a modern home in Minnetonka, Minn.; and a 1906 house in Bozeman, Mont.

- ## More Articles in the Series

- ## Search for Homes for Sale or Rent

- ## Sell Your Home

- Most Emailed
- Most Viewed
- Trending
- Recommended for you

Loading...

Go to Home Page »

## Site Index The New York Times